hass-apps
=========

This is a collection of useful apps and snippets to empower Home Assistant
and AppDaemon even more.


Documentation
-------------

Read the `detailled documentation
<http://hass-apps.readthedocs.io/en/stable/index.html>`_ hosted at
readthedocs.

Some quick links:

* `Getting started
  <http://hass-apps.readthedocs.io/en/stable/getting-started.html>`_
* `Available apps
  <http://hass-apps.readthedocs.io/en/stable/apps/index.html>`_


Donations
---------

I work on this project in my spare time, as most free software developers
do. And of course, I enjoy this work a lot. There is no and will never be
a need to pay anything for using this software.

However, if you want to donate me a cup of coffee, a beer in the evening,
my monthly hosting fees or anything else embellishing my day a little
more, that would be awesome. If you decide doing so, I want to thank you
very much! But please be assured that I'm not presuming anybody to donate,
it's entirely your choice.

|paypal|

.. |paypal| image:: https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif
   :target: https://www.paypal.me/RSchindler

| ETH: 0xa424975a19903F7A6253bA00D5C3F28fACff3C6B
| ZEC: t1RKFyt4qqtqdYfprf8HZoDHRNLNzhe35ED
